@@ -16,10 +16,10 @@ import copy
 import fixtures
 import functools
 import logging as pylogging
-import mock
 import platform
 import sys
 import time
+from unittest import mock
 
 from oslo_log import formatters
 from oslo_log import log as logging
@@ -165,7 +165,7 @@ class DaemonTest(base.BaseTestCase):
         mock_setgid.assert_called_once_with(84)
         mock_setgroups.assert_called_once_with([])
 
-        self.assertItemsEqual(
+        self.assertCountEqual(
             [mock.call(True), mock.call(False)],
             mock_keepcaps.mock_calls)
 
